Changelog
=========

1.9.1.3 (2015-06-03)
--------------------

- Properly register upgrade step so jquerytools can be updated
  in the plone control panel
  [fRiSi]


1.9.1.2 (2014-09-23)
--------------------

- Add jquery.min.map for jQuery 1.9.1 from
  https://raw.githubusercontent.com/jquery/jquery/1.9.1/jquery.min.map and
  modify jquery-1.9.1.js script to include it.
  [thet]


1.9.1.1 (2014-07-10)
--------------------

- Add development profile to include the unminified version of jQuery and the
  migrate plugin.
  [thet]

- Add jQuery migrate plugin.
  [thet]

- Better naming for jQuery resources in filesystem.
  [thet]

- Fix initial-upgrade profile directory declaration.
  [fulv]


1.9.1 (2013-03-06)
------------------

- Add 1.9 branch with jQuery 1.9.1.
  [toutpt]
